@@ -1,17 +1,15 @@
 from logging import Logger
 from pathlib import Path
-from typing import Union, List, Optional, Dict, Any
+from typing import Union, Optional, Dict, Any, Callable
 
-from pyspark import keyword_only
+from spark_pipeline_framework.utilities.capture_parameters import capture_parameters
 from pyspark.ml.param import Param
 from pyspark.sql import DataFrameReader
 from pyspark.sql.dataframe import DataFrame
 from pyspark.sql.types import StructType
 
 from spark_pipeline_framework.logger.yarn_logger import get_logger
-
 from spark_pipeline_framework.progress_logger.progress_logger import ProgressLogger
-
 from spark_pipeline_framework.transformers.framework_transformer.v1.framework_transformer import (
     FrameworkTransformer,
 )
@@ -24,21 +22,23 @@ class FrameworkXmlLoader(FrameworkTransformer):
     """
 
     # noinspection PyUnusedLocal
-    @keyword_only
+    @capture_parameters
     def __init__(
         self,
         view: str,
-        filepath: Union[str, List[str], Path],
+        file_path: Union[Path, str, Callable[[Optional[str]], Union[Path, str]]],
         row_tag: str,
         schema: Optional[StructType] = None,
         name: Optional[str] = None,
         parameters: Optional[Dict[str, Any]] = None,
         progress_logger: Optional[ProgressLogger] = None,
+        stream: bool = False,
+        delta_lake_table: Optional[str] = None,
     ) -> None:
         """
         Initializes the framework_xml_loader
         :param view: The name of the view that the resultant DataFrame will be stored in
-        :param filepath: The path to the xml file to load
+        :param file_path: The path to the xml file to load
         :param row_tag: The row tag of your xml files to treat as a row
         :param schema: The schema to apply to the DataFrame, if not passed schema will be inferred
         :param name: sets the name of the transformer as it will appear in logs
@@ -53,8 +53,10 @@ class FrameworkXmlLoader(FrameworkTransformer):
         self.view: Param[str] = Param(self, "view", "")
         self._setDefault(view=None)
 
-        self.filepath: Param[str] = Param(self, "filepath", "")
-        self._setDefault(filepath=None)
+        self.file_path: Param[
+            Union[Path, str, Callable[[Optional[str]], Union[Path, str]]]
+        ] = Param(self, "file_path", "")
+        self._setDefault(file_path=None)
 
         self.row_tag: Param[str] = Param(self, "row_tag", "")
         self._setDefault(row_tag=None)
@@ -62,21 +64,29 @@ class FrameworkXmlLoader(FrameworkTransformer):
         self.schema: Param[StructType] = Param(self, "schema", "")
         self._setDefault(schema=None)
 
-        if not filepath:
-            raise ValueError("filepath is None or empty")
+        assert (
+            isinstance(file_path, Path)
+            or isinstance(file_path, str)
+            or callable(file_path)
+        ), type(file_path)
+        assert file_path
 
-        self.logger.info(f"Received filepath: {filepath}")
+        self.logger.info(f"Received file_path: {file_path}")
 
         kwargs = self._input_kwargs
         self.setParams(**kwargs)
 
     def _transform(self, df: DataFrame) -> DataFrame:
         view = self.getView()
-        filepath: Union[str, List[str], Path] = self.getFilepath()
+        file_path: Union[
+            Path, str, Callable[[Optional[str]], Union[Path, str]]
+        ] = self.getFilePath()
+        if callable(file_path):
+            file_path = file_path(self.loop_id)
         row_tag: str = self.getRowTag()
         schema: StructType = self.getSchema()
         progress_logger: Optional[ProgressLogger] = self.getProgressLogger()
-        paths = get_absolute_paths(filepath=filepath)
+        paths = get_absolute_paths(file_path=file_path)
         progress_logger and progress_logger.write_to_log(
             f"Loading file for view {view}: {paths}"
         )
@@ -96,8 +106,10 @@ class FrameworkXmlLoader(FrameworkTransformer):
         return self.getOrDefault(self.view)
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
-    def getFilepath(self) -> Union[str, List[str], Path]:
-        return self.getOrDefault(self.filepath)
+    def getFilePath(
+        self,
+    ) -> Union[Path, str, Callable[[Optional[str]], Union[Path, str]]]:
+        return self.getOrDefault(self.file_path)
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getRowTag(self) -> str:
