@@ -9,7 +9,11 @@ from spark_pipeline_framework.transformers.framework_if_else_transformer.v1.fram
 
 
 def run_if_else(
-    enable: Union[bool, Callable[[DataFrame], bool]],
+    *,
+    enable: Optional[Union[bool, Callable[[DataFrame], bool]]] = None,
+    enable_if_view_not_empty: Optional[
+        Union[str, Callable[[Optional[str]], str]]
+    ] = None,
     stages: Union[List[Transformer], Callable[[], List[Transformer]]],
     else_stages: Optional[
         Union[List[Transformer], Callable[[], List[Transformer]]]
@@ -20,7 +24,11 @@ def run_if_else(
     :param enable: a boolean or a function that takes a DataFrame and returns a boolean
     :param stages: list of transformers or a function that returns a list of transformers
     :param else_stages: list of transformers or a function that returns a list of transformers
+    :param enable_if_view_not_empty: enable if this view is not empty
     """
     return FrameworkIfElseTransformer(
-        enable=enable, stages=stages, else_stages=else_stages
+        enable=enable,
+        enable_if_view_not_empty=enable_if_view_not_empty,
+        stages=stages,
+        else_stages=else_stages,
     )
